@@ -124,5 +124,11 @@ class Segments(Base):
     def segment_count(self):
         return len(self.segment_name_list)
 
+    def __getitem__(self, item):
+        return self.segment_list[item]
+
+    def __iter__(self):
+        return iter(self.segment_list)
+
     def __repr__(self):
         return '<Segments: %s>' % self.segment_range
