@@ -59,8 +59,9 @@ def merge_week_by_month(cube, year, month):
         seg_list = segments.list_segments()
         print('segment numbers %s' % len(seg_list))
 
-        if len(seg_list) < 7:
-            print('不够7个segment')
+        if len(seg_list) < 3:
+            print(seg_list)
+            print('不够3个segment')
             continue
 
         # 合并segments; 返回一个job对象
@@ -119,7 +120,7 @@ def check_current_job_num():
     获取当前在跑的任务数
     :return:
     """
-    jobs = client.jobs(status=2)
+    jobs = client.jobs(status=2, size=9999)
     return len(jobs)
 
 
@@ -221,5 +222,10 @@ if __name__ == '__main__':
             if job_num < 3:
                 break
             time.sleep(60)
-        merge_month(cube, year, month)
 
+        try:
+            # merge_month(cube, year, month)
+            merge_week_by_month(cube, 2019, 4)
+        except:
+            print('merging failed')
+            print(traceback.print_exc())
