@@ -1,7 +1,7 @@
 # coding=u8
 import unittest
 from datetime import datetime
-from KE import KE3
+from KE import KE, KE3, KE4
 from KE.v3.segment import Segment
 from KE.client import KE3CONF as CONF
 
@@ -20,6 +20,7 @@ class SegmentTestCase(unittest.TestCase):
 
     def test_segment_properties(self):
         print(self.seg0.name)
+        print(self.seg0.size_kb)
 
     def test_from_json(self):
         segments = self._segments
