@@ -44,5 +44,11 @@ class SegmentsTestCase(unittest.TestCase):
         print(type(seg_list[0]))
         # self.assertNotIsInstance(seg_list[0], Segment)
 
+    def test_get_item(self):
+        print(self.segments[0])
+
+    def test_iter_item(self):
+        for s in self.segments:
+            print(s)
 
 
